# Welcome to pydagoras
![alt text](images/pydagoras.png "pydagoras")

## Introduction
pydagoras is a Python package to create a Directed Acyclical Graph [DAG](https://en.wikipedia.org/wiki/Directed_acyclic_graph) </br>

## Package
pydagoras can be installed from PyPi, which can be reached using the Python link the bottom of this documentation.</br>
For further details see [Package](package.md)

## Example use
blah


## Demo
For further details see [Demo](demo.md)
blah

